@@ -41,14 +41,11 @@ Java_org_gnome_gtk_GtkMain_gtk_1init
 	jstring _arg;
 	gchar* arg;
 
-	bindings_java_logging_init();
-
-	bindings_java_threads_init(env, _lock);
-	
-	g_thread_init(NULL);
-	gdk_threads_init();
-
-	g_set_prgname("java");
+	/*
+	 * The call to g_threads_init() needs to be be the very first thing
+	 * that happens in our use of GLib; it will have happened care of
+	 * the static initializer in [org.gnome.gib] Plumbing.
+	 */
 
 	// convert args
 	if (_args == NULL) {
@@ -60,7 +57,7 @@ Java_org_gnome_gtk_GtkMain_gtk_1init
 
 	for (i = 0; i < argc; i++) {
 		_arg = (jstring) (*env)->GetObjectArrayElement(env, _args, i);
-		arg = (gchar*)(*env)->GetStringUTFChars(env, _arg, NULL);
+		arg = (gchar*) bindings_java_getString(env, _arg);
 		argv[i+1] = arg;
 	}
 
@@ -74,6 +71,10 @@ Java_org_gnome_gtk_GtkMain_gtk_1init
 
 	// call function
 	gtk_init(&argc, &argv);
+
+ 	/*
+	 * TODO can we release argv elements?
+	 */
  
 	/*
 	 * Work around for what may be bug #85715. It appears that the root
