@@ -1,7 +1,7 @@
 /*
  * ProgressBar.java
  *
- * Copyright (c) 2007-2008 Operational Dynamics Consulting Pty Ltd, and Others
+ * Copyright (c) 2007-2009 Operational Dynamics Consulting Pty Ltd, and Others
  * 
  * The code in this file, and the library it is a part of, are made available
  * to you by the authors under the terms of the "GNU General Public Licence,
@@ -28,6 +28,7 @@ package org.gnome.gtk;
  * 
  * @author Andrew Cowie
  * @author Vreixo Formoso
+ * @author Bruno Dusausoy
  * @since 4.0.3
  */
 public class ProgressBar extends Widget
@@ -58,6 +59,15 @@ public class ProgressBar extends Widget
         GtkProgressBar.setText(this, text);
     }
 
+    /**
+     * Getting the text superimposed on the ProgressBar itself.
+     * 
+     * @since 4.0.10
+     */
+    public String getText() {
+        return GtkProgressBar.getText(this);
+    }
+
     /**
      * Set the fraction of the ProgressBar that shows as completed or
      * "filled-in".
@@ -105,4 +115,57 @@ public class ProgressBar extends Widget
     public void pulse() {
         GtkProgressBar.pulse(this);
     }
+
+    /**
+     * Set orientation of this ProgressBar
+     * 
+     * @since 4.0.10
+     */
+    public void setOrientation(ProgressBarOrientation orientation) {
+        GtkProgressBar.setOrientation(this, orientation);
+    }
+
+    /**
+     * Get orientation currently in effect in this ProgressBar
+     * 
+     * @since 4.0.10
+     */
+    public ProgressBarOrientation getOrientation() {
+        return GtkProgressBar.getOrientation(this);
+    }
+
+    /**
+     * Set the progress bar pulse step. That means the amount of progress to
+     * perform each time {@link ProgressBar#pulse() pulse()}; is called.
+     * 
+     * @param fraction
+     *            a value between 0.0 and 1.0
+     * @throws IllegalArgumentException
+     *             If fraction is greater than 1.0 or less than 0.0
+     * @since 4.0.10
+     */
+    public void setPulseStep(double fraction) {
+        if ((fraction < 0.0) || (fraction > 1.0)) {
+            throw new IllegalArgumentException("fraction must be between 0.0 and 1.0, inclusive.");
+        }
+        GtkProgressBar.setPulseStep(this, fraction);
+    }
+
+    /**
+     * Get the current progress bar pulse step
+     * 
+     * @since 4.0.10
+     */
+    public double getPulseStep() {
+        return GtkProgressBar.getPulseStep(this);
+    }
+
+    /**
+     * Get the current progress bar fraction
+     * 
+     * @since 4.0.10
+     */
+    public double getFraction() {
+        return GtkProgressBar.getFraction(this);
+    }
 }
