@@ -1,9 +1,9 @@
 /*
  * VirtualGenerator.java
  *
- * Copyright (c) 2007 Operational Dynamics Consulting Pty Ltd
+ * Copyright (c) 2007-2009 Operational Dynamics Consulting Pty Ltd
  * 
- * The code in this file, and the library it is a part of, are made available
+ * The code in this file, and the program it is a part of, are made available
  * to you by the authors under the terms of the "GNU General Public Licence,
  * version 2" See the LICENCE file for the terms governing usage and
  * redistribution.
@@ -55,11 +55,11 @@ public class VirtualGenerator extends FunctionGenerator
      */
     public VirtualGenerator(final DefsFile data, final String blockName, final String gReturnType,
             final String[][] gParameters) {
-        super(data, "connect", gReturnType, null, gParameters);
+        super(data, "connect", gReturnType, null, gParameters, 'f');
 
-        this.javaSignalClass = toAllCaps(blockName);
-        this.cSignalName = blockName;
-        this.receiverMethodName = toCamel("handle_" + blockName);
+        this.javaSignalClass = toPascalCase(blockName) + "Signal";
+        this.cSignalName = blockName.replace('_', '-');
+        this.receiverMethodName = toCamel("receive_" + blockName);
         this.interfaceMethodName = toCamel("on_" + blockName);
     }
 
@@ -77,7 +77,7 @@ public class VirtualGenerator extends FunctionGenerator
         out.print(proxyType.bindingsClass);
         out.print(".");
         out.print(javaSignalClass);
-        out.print(" handlerInstance) {");
+        out.print(" handlerInstance, boolean after) {");
         out.print("\n");
     }
 
@@ -91,7 +91,7 @@ public class VirtualGenerator extends FunctionGenerator
         out.print(proxyType.bindingsClass);
         out.print(".class, \"");
         out.print(cSignalName);
-        out.print("\");\n");
+        out.print("\", after);\n");
 
         out.print("    }\n");
     }
