@@ -1,7 +1,7 @@
 /*
  * ValidateScreensAndDisplays.java
  *
- * Copyright (c) 2007 Operational Dynamics Consulting Pty Ltd
+ * Copyright (c) 2007-2009 Operational Dynamics Consulting Pty Ltd
  * 
  * The code in this file, and the suite it is a part of, are made available
  * to you by the authors under the terms of the "GNU General Public Licence,
@@ -10,13 +10,13 @@
  */
 package org.gnome.gdk;
 
-import org.gnome.gtk.TestCaseGtk;
+import org.gnome.gtk.GraphicalTestCase;
 import org.gnome.gtk.Window;
 
 /**
  * @author Andrew Cowie
  */
-public class ValidateScreensAndDisplays extends TestCaseGtk
+public class ValidateScreensAndDisplays extends GraphicalTestCase
 {
     /*
      * This tests the workaround employed in Gdk.c to manually increase the
